@@ -57,6 +57,16 @@ class Scheduler(object):
         self.scheduler.run()
 
 
+def file_read(filename):
+    contents = open(filename, 'r').read()
+    return contents
+
+
+def file_write(filename, contents):
+    f = open(filename, 'w')
+    f.write(contents)
+
+
 def logged_in():
     """Returns True is an user is logged in.
     At the moment only works on Ubuntu 12.04
